@@ -306,11 +306,19 @@ insert_attr (SuggestionsData  *data,
         insert_id (data, original_contact, values->data, _("email"));
     } else if (name_quark == OSSO_ABOOK_QUARK_VCA_TEL) {
         insert_phone (data, original_contact, values->data);
-    } else if (name_quark == OSSO_ABOOK_QUARK_VCA_FN) {
+    } else if (name_quark == OSSO_ABOOK_QUARK_VCA_N) {
         const EContactName *name;
         /* There's no way to convert the GList in a EContactName... */
         name = e_contact_get_const (E_CONTACT (flat_contact), E_CONTACT_NAME);
         insert_full_name (data, original_contact, name);
+    } else if (name_quark == OSSO_ABOOK_QUARK_VCA_FN) {
+        if (!e_contact_get_const (E_CONTACT (flat_contact), E_CONTACT_NAME)) {
+            /* There is a FN but not an N, so let's parse FN */
+            EContactName *name;
+            name = e_contact_name_from_string (values->data);
+            insert_full_name (data, original_contact, name);
+            e_contact_name_free (name);
+        }
     } else if (name_quark == OSSO_ABOOK_QUARK_VCA_NICKNAME) {
         insert_nickname (data, original_contact, values->data);
     } else if (g_hash_table_lookup (data->im_field_quarks,
